﻿using ELTE.TicTacToeGame.Model;
using ELTE.TicTacToeGame.Persistence;
using ELTE.TicTacToeGame.ViewModel;
using ELTE.TicTacToeGame.View;

namespace ELTE.TicTacToeGame;

public partial class App : Application
{
    #region Private fields

    private ITicTacToeDataAccess _persistence;
    private ITicTacToeModel _model;

    #endregion

    #region Constructors

    public App()
	{
		InitializeComponent();

        _persistence = new TicTacToeTextFileDataAccess(); // platformfüggetlen perzisztencia
        _model = new BasicTicTacToeModel(_persistence);

        MainPage = new AppShell(_model);
	}

    #endregion

    #region Application life-cycle methods

    protected override Window CreateWindow(IActivationState? activationState)
    {
        Window window = base.CreateWindow(activationState);

        window.Created += async (s, e) =>
        {
            _model.NewGame(); // indításkor új játékot kezdünk

            // betöltjük a felfüggesztett játékot, amennyiben van
            try
            {
                await _model.LoadGameAsync(
                    Path.Combine(FileSystem.AppDataDirectory, "SuspendedGame"));
            }
            catch { }
        };

        window.Resumed += async (s, e) =>
        {
            // betöltjük a felfüggesztett játékot, amennyiben van
            try
            {
                await _model.LoadGameAsync(
                    Path.Combine(FileSystem.AppDataDirectory, "SuspendedGame"));
            }
            catch { }
        };

        window.Stopped += async (s, e) =>
        {
            // elmentjük a jelenleg folyó játékot
            try
            {
                await _model.SaveGameAsync(
                    Path.Combine(FileSystem.AppDataDirectory, "SuspendedGame"));
            }
            catch { }
        };

        return window;
    }

    #endregion
}
